Changelog
=========

1.0.0 release (2018-07-25)
--------------------------

Framework-agnostic mAP computation python API for fast and easy validation.

* Initial release


1.0.1 release (2021-01-21)
--------------------------

* Packaging for upload
